@@ -786,7 +786,7 @@ couchdb_document_contact_address_get_street (CouchDBStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
-	return couchdb_struct_field_get_string_field (sf, "address1");
+	return couchdb_struct_field_get_string_field (sf, "street");
 }
 
 void
@@ -794,7 +794,7 @@ couchdb_document_contact_address_set_street (CouchDBStructField *sf, const char
 {
 	g_return_if_fail (sf != NULL);
 
-	couchdb_struct_field_set_string_field (sf, "address1", street);
+	couchdb_struct_field_set_string_field (sf, "street", street);
 }
 
 const char *
